==> doc-adapter-1.0.1.tgz: package/src/splitByPage/Pages.ts <==
import { EOrientation } from '../types';
import { Page } from './Page';
import * as utils from '../utils'
import { TableElem } from './Table';

export class Pages {
  private pages: Page[] = []
  private orientation: EOrientation
  private templatePage: string

  constructor(orientation: EOrientation, templatePage: string) {
    this.pages.push(new Page(orientation, templatePage))
    this.templatePage = templatePage
    this.orientation = orientation
  }

  private createPage() {
    const page = new Page(this.orientation, this.templatePage)
    this.pages.push(page)
    return page
  }

  get lastPage() {
    return this.pages[this.pages.length - 1]
  }
  get pagesContent() {
    return this.pages.reduce((accum, page) => accum + page.pageContent, '')
  }

  async insertElem(elem: HTMLDivElement) {
    const type = utils.identificationRowElem(elem)
    
    switch (type) {
      case 'simple':
        this.insertSimpleElem(elem)
        break;
      case 'image':
        await this.insertImage(elem)
        break
      case 'table':
        this.insertTable(elem)
        break
    }
  }

  private insertSimpleElem(elem: HTMLDivElement) {
    // const elem = _elem.cloneNode(true) as HTMLDivElement
    if (elem.offsetHeight > this.lastPage.height.fullHeight) {
      const div = document.createElement('div')
      div.textContent = 'Элемент слишком большой и не может уместиться на странице'
    }
    if (elem.offsetHeight <= this.lastPage.height.balanceHeight) {
      this.lastPage.insertElem(elem)
      return
    }

    this.createPage().insertElem(elem)
  }

  private insertTable(elem: HTMLDivElement) {
    const table = new TableElem(elem, this.orientation)
    while (!table.isEmpty) {
      if (table.minHeght > this.lastPage.height.balanceHeight)
        this.createPage()
      const partTable = table.getTable(this.lastPage.height.balanceHeight)
      // this.insertSimpleElem(partTable)
      this.lastPage.insertElem(partTable)
    }
  }

  private async insertImage(elem: HTMLDivElement) {
    // const elem = _elem.cloneNode(true) as HTMLDivElement
    const img = elem.querySelector('img')!
    await new Promise<void>((resolve, reject) => {
      img.onload = () => resolve()
      setTimeout(() => { reject('Не могу высчитать высоту картинки, слишком долго грузится') }, 60000)
    })
    this.insertSimpleElem(elem)
  }

}

==> doc-adapter-1.0.20.tgz: package/src/splitByPage/Pages.ts <==
import { EOrientation } from '../types'
import { Page } from './Page'
import { TableElem } from './Table'
import * as utils from '../utils'

export class Pages {
  private pages: Page[] = []
  private orientation: EOrientation
  private templatePage: string

  constructor(orientation: EOrientation, templatePage: string) {
    this.pages.push(new Page(orientation, templatePage))
    this.templatePage = templatePage
    this.orientation = orientation
  }

  private createPage() {
    const page = new Page(this.orientation, this.templatePage)
    this.pages.push(page)
    return page
  }

  get lastPage() {
    return this.pages[this.pages.length - 1]
  }
  get pagesContent() {
    return this.pages.reduce((accum, page) => accum + page.pageContent, '')
  }

  async insertElem(elem: HTMLDivElement) {
    const type = utils.identificationRowElem(elem)
    
    switch (type) {
      case 'simple':
        this.insertSimpleElem(elem)
        break;
      case 'image':
        await this.insertImage(elem)
        break
      case 'table':
        this.insertTable(elem)
        break
    }
  }

  private insertSimpleElem(elem: HTMLDivElement) {
    // const elem = _elem.cloneNode(true) as HTMLDivElement
    if (elem.offsetHeight > this.lastPage.height.fullHeight) {
      const div = document.createElement('div')
      div.textContent = 'Элемент слишком большой и не может уместиться на странице'
    }
    if (elem.offsetHeight <= this.lastPage.height.balanceHeight) {
      this.lastPage.insertElem(elem)
      return
    }

    this.createPage().insertElem(elem)
  }

  private insertTable(elem: HTMLDivElement) {
    const table = new TableElem(elem, this.orientation)
    while (!table.isEmpty) {
      if(table.minHeght > this.lastPage.height.balanceHeight && table.minHeght > this.lastPage.height.fullHeight){
        return 
      }
      if (table.minHeght > this.lastPage.height.balanceHeight){
        this.createPage()
      }
      const partTable = table.getTable(this.lastPage.height.balanceHeight)
      // this.insertSimpleElem(partTable)
      this.lastPage.insertElem(partTable)
    }
  }

  private async insertImage(elem: HTMLDivElement) {
    // const elem = _elem.cloneNode(true) as HTMLDivElement
    const img = elem.querySelector('img')!
    await new Promise<void>((resolve, reject) => {
      img.onload = () => resolve()
      setTimeout(() => { reject('Не могу высчитать высоту картинки, слишком долго грузится') }, 60000)
    })
    this.insertSimpleElem(elem)
  }

}
